.. Copyright (C) 2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2016 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The :command:`apt-listchanges` package is used to notify system administrator about
package changes from Changelog and NEWS files. The role will configure this
script to send that information via email messages to specified addresses.
